@@ -40,7 +40,13 @@ assert('kable() works with the jira format', {
 })
 
 assert('kable() works with the org format', {
-  (kable2(m, 'org') %==% c('|   |  x|  y|', '|:--+--:+--:|', '|a  |  1|  2|'))
+  (kable2(m, 'org') %==%
+    c('|   |  x|  y|', '|<l>|<r>|<r>|', '|---+---+---|', '|a  |  1|  2|'))
+  m2 = m; colnames(m2) = NULL  # no column names
+  (kable2(m2, 'org') %==% c('|<l>|<r>|<r>|', '|a  |  1|  2|'))
+  # the case of only one column
+  (kable2(m[, 1, drop = FALSE], 'org', row.names = FALSE) %==%
+    c('|  x|', '|<r>|', '|---|', '|  1|'))
 })
 
 assert('kable() does not add extra spaces to character columns', {
@@ -111,9 +117,20 @@ x\\\\
 \\end{tabular}')
 })
 
+assert('kable() does not trim escaped spaces at the end', {
+  (kable2(data.frame(x = '\\ '), 'latex', escape =FALSE ) %==% '
+\\begin{tabular}{l}
+\\hline
+x\\\\
+\\hline
+\\ \\\\
+\\hline
+\\end{tabular}')
+})
+
 assert('kable() escapes HTML special characters by default', {
   (kable2(data.frame(x = c('10<>', '5&2'), y = c('3>8', '"40"')), 'html') %==%
-     '<table>\n <thead>\n  <tr>\n   <th style="text-align:left;"> x </th>\n   <th style="text-align:left;"> y </th>\n  </tr>\n </thead>\n<tbody>\n  <tr>\n   <td style="text-align:left;"> 10&lt;&gt; </td>\n   <td style="text-align:left;"> 3&gt;8 </td>\n  </tr>\n  <tr>\n   <td style="text-align:left;"> 5&amp;2 </td>\n   <td style="text-align:left;"> &quot;40&quot; </td>\n  </tr>\n</tbody>\n</table>')
+     '<table>\n <thead>\n  <tr>\n   <th style="text-align:left;"> x </th>\n   <th style="text-align:left;"> y </th>\n  </tr>\n </thead>\n<tbody>\n  <tr>\n   <td style="text-align:left;"> 10&lt;&gt; </td>\n   <td style="text-align:left;"> 3&gt;8 </td>\n  </tr>\n  <tr>\n   <td style="text-align:left;"> 5&amp;2 </td>\n   <td style="text-align:left;"> "40" </td>\n  </tr>\n</tbody>\n</table>')
 })
 
 assert('kable() doesn\'t escape HTML special characters when escape = FALSE', {
